Skip to contents

Returns the intercept and regression coefficient point estimates carried by a boot_ame object (the estimates the bootstrap quantifies). For their bootstrap standard errors and intervals see confint.boot_ame and vcov.boot_ame.

Usage

# S3 method for class 'boot_ame'
coef(object, ...)

Arguments

object

a boot_ame object.

...

ignored.

Value

A named numeric vector of coefficient point estimates.