Computes the design socioarray of covariate values for an AME fit
design_array_listwisedel(Xrow=NULL,Xcol=NULL,Xdyad=NULL,intercept=TRUE,n)an n x n x (pr+pc+pd+intercept) 3-way array
an n x pr matrix of row covariates
an n x pc matrix of column covariates
an n x n x pd array of dyadic covariates
logical
number of rows/columns
Cassy Dorff, Shahryar Minhas, Tosin Salau