Skip to contents

An extension of the 'amen' package specifically designed for longitudinal network analysis. This package provides tools for fitting Additive and Multiplicative Effects (AME) models to longitudinal/replicated relational data with several extensions: (1) handling of changing actor compositions across time periods, allowing for networks with different sets of actors at each time point; (2) significant performance improvements through C++ implementations via Rcpp and RcppArmadillo; (3) specialized functions for temporal network dynamics. The package supports six data types: normal (nrm), binary (bin), ordinal (ord), Poisson count (poisson), censored binary (cbin), and fixed-rank nomination (frn). Based on the AME framework originally developed by Hoff (2009) and Hoff, Fosdick, Volfovsky and Stovel (2013).

Details

Estimators. The package offers two estimation routes:

  • ame / lame – the Bayesian MCMC estimators, for calibrated posterior inference (cross-sectional and longitudinal respectively).

  • ame_als / lame_als – a fast, MCMC-free point estimator by iterative block coordinate descent, with bootstrap uncertainty via ame_als_bootstrap. Use it for rapid model exploration, rank selection and starting values; use the MCMC estimators for final inference.

Package:lame
Type:Package
License:MIT

Author

Shahryar Minhas, Tosin Salau, Cassy Dorff

Maintainer: Shahryar Minhas minhassh@msu.edu

Examples

# \donttest{
data(YX_nrm)
fit <- ame(YX_nrm$Y, Xdyad = YX_nrm$X, burn = 10, nscan = 100, odens = 1,
           family = "normal", verbose = FALSE)
summary(fit)
#> 
#> Regression coefficients:
#>                 pmean   psd  z-stat p-val
#> intercept_dyad -2.720 0.103 -26.531 0.000
#> rgpa_dyad       0.221 0.099   2.236 0.025
#> rsmoke_dyad     0.242 0.137   1.770 0.077
#> cgpa_dyad       0.172 0.032   5.453 0.000
#> csmoke_dyad     0.111 0.045   2.470 0.014
#> igrade_dyad     1.130 0.028  41.014 0.000
#> igpa_dyad       0.052 0.018   2.932 0.003
#> ismoke_dyad     0.026 0.029   0.891 0.373
#> 
#> Variance parameters:
#>     pmean   psd
#> va  0.842 0.135
#> cab 0.102 0.033
#> vb  0.084 0.014
#> rho 0.920 0.002
#> ve  1.057 0.017
# }