Learn R Programming

lame (version 1.3.4)

rUV_dynamic_fc: Gibbs sampling of dynamic U and V with AR(1) evolution

Description

Updates latent factor positions U and V that evolve over time according to an AR(1) process: u_{i,t} = rho * u_{i,t-1} + epsilon_{i,t}

Usage

rUV_dynamic_fc(U, V, ET, rho_uv, sigma_uv, s2, shrink=TRUE, symmetric=FALSE)

Value

list with updated U and V arrays

Arguments

U

3D array of current U positions (n x R x T)

V

3D array of current V positions (n x R x T)

ET

3D array of residuals (n x n x T)

rho_uv

AR(1) autoregressive parameter for latent positions

sigma_uv

Innovation standard deviation for latent positions

s2

dyadic variance

shrink

whether to apply shrinkage (default TRUE)

symmetric

whether the network is symmetric (default FALSE)

Author

Cassy Dorff, Shahryar Minhas, Tosin Salau