Learn R Programming

lame (version 1.3.4)

rZ_bin_bip_batch_cpp: Batch binary Z sampling across all time periods (bipartite, rho=0)

Description

Vectorized probit update for bipartite binary networks without dyadic correlation.

Usage

rZ_bin_bip_batch_cpp(Z, EZ, Y)

Value

Updated Z array

Arguments

Z

3D array of latent values (nA x nB x T)

EZ

3D array of expected values (nA x nB x T)

Y

3D array of observed values (nA x nB x T)