Skip to contents

Number of dominance encounters between 28 female bighorn sheep. Cell (i,j) records the number of times sheep i dominated sheep j. From Hass (1991).

Format

A list consisting of the following:

  • dom: a directed socioarray recording the number of dominance encounters.

  • age: the age of each sheep in years.

Originally available at http://moreno.ss.uci.edu/data.html#sheep (site no longer accessible).