Skip to contents

Draws a latent Gaussian array with the given dyadic correlation and thresholds it at zero to produce a binary (0/1) sociomatrix. Self-ties on the diagonal of a square (unipartite) matrix are set to NA; rectangular (bipartite) matrices are returned with every entry populated.

Usage

simY_bin(EZ, rho)

Arguments

EZ

matrix giving the expected value of the latent Z matrix

rho

dyadic correlation

Value

a binary matrix matching the dimensions of EZ

Author

lame authors