Skip to contents

Maps a numeric vector to normal quantiles determined by the ranks of its observed entries, leaving missing values as NA.

Usage

zscores(y)

Arguments

y

a numeric vector

Value

a numeric vector of the same length as y

Author

lame authors