Learn R Programming

lame (version 1.3.4)

coef.boot_ame: Point estimates from a fast AME bootstrap

Description

Returns the intercept and regression coefficient point estimates carried by a boot_ame object (the estimates the bootstrap quantifies). For their bootstrap standard errors and intervals see confint.boot_ame and vcov.boot_ame.

Usage

# S3 method for boot_ame
coef(object, ...)

Value

A named numeric vector of coefficient point estimates.

Arguments

object

a boot_ame object.

...

ignored.