Get fitted object from MCMC results
Arguments
- start_vals
List object that is null or contains starting values
- Y
dependent variable in array format
- family
character vector (e.g. 'bin', 'nrm') specifying family type
- xP
number of exogenous covariates
- rvar
logical indicating whether to include sender random effects
- cvar
logical indicating whether to include receiver random effects
- R
Number of dimensions for multiplicative effects
- odmax
vector of maximum ranks for cbin/frn families (optional)
- bip
logical;
TRUEfor a bipartite (rectangular) panel, in which case the Poisson start values keep the diagonal of a square matrix as a real cell
Details
In addition to the slots listed below, any of the dynamic
hyperparameter scalars rho_uv, sigma_uv, rho_ab,
and sigma_ab present in start_vals (for example from
als_start_vals) are passed through so a dynamic MCMC run
can warm-start them.