Learn R Programming

lame (version 1.3.4)

lame-package: Longitudinal Additive and Multiplicative Effects Models for Networks

Description

An extension of the 'amen' package specifically designed for longitudinal network analysis. This package provides tools for fitting Additive and Multiplicative Effects (AME) models to longitudinal/replicated relational data with several extensions: (1) handling of changing actor compositions across time periods, allowing for networks with different sets of actors at each time point; (2) significant performance improvements through C++ implementations via Rcpp and RcppArmadillo; (3) specialized functions for temporal network dynamics. The package supports six data types: normal (nrm), binary (bin), ordinal (ord), Poisson count (poisson), censored binary (cbin), and fixed-rank nomination (frn). Based on the AME framework originally developed by Hoff (2009) and Hoff, Fosdick, Volfovsky and Stovel (2013).

Arguments

Author

Shahryar Minhas, Tosin Salau, Cassy Dorff

Maintainer: Shahryar Minhas minhassh@msu.edu

Details

Estimators. The package offers two estimation routes:

  • ame / lame -- the Bayesian MCMC estimators, for calibrated posterior inference (cross-sectional and longitudinal respectively).

  • ame_als / lame_als -- a fast, MCMC-free point estimator by iterative block coordinate descent, with bootstrap uncertainty via ame_als_bootstrap. Use it for rapid model exploration, rank selection and starting values; use the MCMC estimators for final inference.

Package:lame
Type:Package
License:MIT

Examples

Run this code
# \donttest{
data(YX_nrm)
fit <- ame(YX_nrm$Y, Xdyad = YX_nrm$X, burn = 10, nscan = 100, odens = 1,
           family = "normal", verbose = FALSE)
summary(fit)
# }



Run the code above in your browser using DataLab