Options for saving posterior samples during MCMC
Value
List of posterior saving options, to be passed to the
posterior_opts argument of ame:
ame(Y, ..., posterior_opts = posterior_options(save_UV = TRUE))
Options for saving posterior samples during MCMC
List of posterior saving options, to be passed to the
posterior_opts argument of ame:
ame(Y, ..., posterior_opts = posterior_options(save_UV = TRUE))