Options for saving posterior samples during MCMC
posterior_options(save_UV = FALSE, save_ab = FALSE, thin_UV = 10, thin_ab = 10)List of posterior saving options, to be passed to the
posterior_opts argument of ame:
ame(Y, ..., posterior_opts = posterior_options(save_UV = TRUE))
Logical; whether to save samples of U and V matrices (default FALSE)
Logical; whether to save samples of additive effects a and b (default FALSE)
Integer; thinning interval for U/V samples (default 10)
Integer; thinning interval for a/b samples (default 10)
Cassy Dorff, Shahryar Minhas, Tosin Salau