Print the priors used by an AME / LAME / ame_als fit
Source:R/ame_als_methods_extra.R
prior_summary.RdBayesian-hygiene helper modelled on rstanarm::prior_summary().
Prints the priors that were actually in effect for a fit, with defaults
filled in. For ame_als fits it just states that the estimator is a
frequentist point estimator and there are no priors.