Learn R Programming

lame (version 1.3.4)

prior_summary: Print the priors used by an AME / LAME / ame_als fit

Description

Bayesian-hygiene helper modelled on rstanarm::prior_summary(). Prints the priors that were actually in effect for a fit, with defaults filled in. For ame_als fits it just states that the estimator is a frequentist point estimator and there are no priors.

Usage

prior_summary(object, ...)

# S3 method for default prior_summary(object, ...)

# S3 method for ame prior_summary(object, ...)

# S3 method for lame prior_summary(object, ...)

# S3 method for ame_als prior_summary(object, ...)

Value

object, invisibly.

Arguments

object

a fitted ame, lame, or ame_als object.

...

ignored.