Learn R Programming

lame (version 1.3.4)

rUV_rep_fc: Gibbs sampling of U and V from replicated relational data

Description

Draws the multiplicative-effect matrices U and V from their full conditional distributions, pooling information across the replicate slices of a residual array. Each factor column is updated in turn from its Gaussian full conditional, optionally under a hierarchical shrinkage prior on the stacked (U, V) rows.

Usage

rUV_rep_fc(E.T,U,V,rho,s2=1,shrink=TRUE)

Value

U

a new value of U

V

a new value of V

Arguments

E.T

Array of square residual relational matrices (additive effects and covariates removed). The third margin indexes replicates.

U

current value of U

V

current value of V

rho

dyadic correlation

s2

dyadic variance

shrink

adaptively shrink the factors with a hierarchical prior

Author

lame authors