Updates the latent variable Z in a Poisson AME model using a Metropolis-Hastings step. The model assumes y_{i,j} ~ Poisson(exp(z_{i,j})) where z_{i,j} is the latent variable representing the log mean.
rZ_pois_fc(Z, EZ, rho, s2, Y)updated value of Z
a square matrix, the current value of the latent variable
expected value of Z (regression effects + random effects)
dyadic correlation
dyadic variance (overdispersion parameter)
square relational matrix of observed counts
Cassy Dorff, Shahryar Minhas, Tosin Salau