Learn R Programming

lame (version 1.3.4)

simY_bin: Simulate a binary relational matrix from latent means

Description

Draws a latent Gaussian array with the given dyadic correlation and thresholds it at zero to produce a binary (0/1) sociomatrix. Self-ties on the diagonal of a square (unipartite) matrix are set to NA; rectangular (bipartite) matrices are returned with every entry populated.

Usage

simY_bin(EZ, rho)

Value

a binary matrix matching the dimensions of EZ

Arguments

EZ

matrix giving the expected value of the latent Z matrix

rho

dyadic correlation

Author

lame authors