Returns the sample covariance matrix of the bootstrap replicate
intercept + regression coefficients of a boot_ame object – the
covariance underlying the reported standard errors and confidence intervals.
Usage
# S3 method for class 'boot_ame'
vcov(object, ...)