Learn R Programming

lame (version 1.3.4)

vcov.boot_ame: Bootstrap covariance of the regression coefficients

Description

Returns the sample covariance matrix of the bootstrap replicate intercept + regression coefficients of a boot_ame object -- the covariance underlying the reported standard errors and confidence intervals.

Usage

# S3 method for boot_ame
vcov(object, ...)

Value

A covariance matrix over the intercept and regression coefficients.

Arguments

object

a boot_ame object.

...

ignored.