Returns the sample covariance matrix of the bootstrap replicate
intercept + regression coefficients of a boot_ame object -- the
covariance underlying the reported standard errors and confidence intervals.
# S3 method for boot_ame
vcov(object, ...)A covariance matrix over the intercept and regression coefficients.
a boot_ame object.
ignored.