R/zscores.R
zscores.Rd
Maps a numeric vector to normal quantiles determined by the ranks of its observed entries, leaving missing values as NA.
NA
zscores(y)
a numeric vector
a numeric vector of the same length as y
y
lame authors