Learn R Programming

lame (version 1.3.4)

zscores: rank-based z-scores

Description

Maps a numeric vector to normal quantiles determined by the ranks of its observed entries, leaving missing values as NA.

Usage

zscores(y)

Value

a numeric vector of the same length as y

Arguments

y

a numeric vector

Author

lame authors