powered by
Maps a numeric vector to normal quantiles determined by the ranks of its observed entries, leaving missing values as NA.
NA
zscores(y)
a numeric vector of the same length as y
y
a numeric vector
lame authors